@@ -11,7 +11,7 @@ class CliTest(unittest.TestCase):
 
     def test_install(self):
         file = "echo 'github.com/MichaelKim0407/tutorial-pip-package:my-pip-package https=true' > requirements-gpip.txt"
-        command = "gpip install ./requirements-gpip.txt --debug"
+        command = "gpip install ./requirements-gpip.txt --debug --user"
         self.assertEqual(0,os.system(file))
         self.assertEqual(0,os.system(command))
 
